import "highlight.js";
import type { Node as ProseMirrorNode } from "prosemirror-model";
import { Plugin } from "prosemirror-state";
import { Decoration } from "prosemirror-view";
/**
 * Creates a plugin that highlights the contents of all nodes (via Decorations) with a type passed in blockTypes
 * @param hljs The pre-configured instance of highlightjs to use for parsing
 * @param nodeTypes An array containing all the node types to target for highlighting
 * @param languageExtractor A method that is passed a prosemirror node and returns the language string to use when highlighting that node; defaults to using `node.attrs.params`
 */
export declare function highlightPlugin(hljs: HLJSApi, nodeTypes?: string[], languageExtractor?: (node: ProseMirrorNode) => string): Plugin<any, any>;
/**
 * Gets all highlighting decorations from a ProseMirror document
 * @param doc The doc to search applicable blocks to highlight
 * @param hljs The pre-configured highlight.js instance to use for parsing
 * @param nodeTypes An array containing all the node types to target for highlighting
 * @param languageExtractor A method that is passed a prosemirror node and returns the language string to use when highlighting that node
 */
export declare function getHighlightDecorations(doc: ProseMirrorNode, hljs: HLJSApi, nodeTypes: string[], languageExtractor: (node: ProseMirrorNode) => string): Decoration<{
    [key: string]: any;
}>[];
